==> bootstrap-7.1.17.tgz: package/tsDist/components/dashboard/widgets/YourKis/getKisStats.js <==
import React from 'react';
import { FilterValue } from '../../types';
export var getKiStats = function (counts, openKim) { return [
    {
        title: (React.createElement("span", null,
            "Knowledge Items in ",
            React.createElement("b", null, "Validation Mode"))),
        description: (React.createElement("div", null,
            React.createElement("strong", null, "What it is:"),
            React.createElement("p", null, "If you deploy a KI from HIRO KAT into Validation Mode, the KI will be checked against all incoming tasks if it would be working in the affected issues"),
            React.createElement("strong", null, "What does it tell"),
            React.createElement("p", null, "The statistics about the potential application for each KI can be found in HIRO KIM. The statistics can give you an indication if the quality of the affected KI is sufficient or if improvement is required"))),
        value: counts.validation,
        action: function () { return openKim(FilterValue.DEPLOYED_TO_VALIDATE); },
    },
    {
        title: (React.createElement("span", null,
            React.createElement("b", null, "Undeployed"),
            " Knowledge Items")),
        description: (React.createElement("div", null,
            React.createElement("strong", null, "What it is:"),
            React.createElement("p", null, "If a KI is not being deployed into the testing or live mode from HIRO KAT - the KI will remain in the underplayed state. Like that the affected KI will not be tested or applied in an automation process"),
            React.createElement("strong", null, "When is this useful"),
            React.createElement("p", null, "In case you are still working on a KI or want to ask a peer for review - it makes sense to leave the KI in the Undeployed state."))),
        value: counts.undeployed,
        action: function () { return openKim(FilterValue.UNDEPLOYED); },
    },
    {
        title: (React.createElement("span", null,
            React.createElement("b", null, "Live"),
            " Knowledge Items")),
        description: (React.createElement("div", null,
            React.createElement("strong", null, "What it is:"),
            React.createElement("p", null, "If you deploy a KI into the Live Mode, this KI will be triggered during automation solution creation and will help to solve automation tasks"),
            React.createElement("strong", null, "Where can I inspect this?"),
            React.createElement("p", null, "All statistics about the performance of a KI no matter if in live or test mode can be found in the HIRO KI Manager application (KIM)"))),
        value: counts.deployed,
        action: function () { return openKim(FilterValue.DEPLOYED_TO_LIVE); },
    },
    {
        title: 'Total Knowledge Items available',
        description: '',
        value: counts.total,
        primary: true,
        action: function () { return openKim(); },
    },
]; };

==> bootstrap-7.2.31.tgz: package/tsDist/components/dashboard/widgets/YourKis/getKisStats.js <==
import React from 'react';
export var getKiStats = function (counts, openKim) { return [
    {
        title: (React.createElement("span", null,
            "Knowledge Items in ",
            React.createElement("b", null, "Validation Mode"))),
        description: (React.createElement("div", null,
            React.createElement("strong", null, "What it is:"),
            React.createElement("p", null, "If you deploy a KI from HIRO KAT into Validation Mode, the KI will be checked against all incoming tasks if it would be working in the affected issues"),
            React.createElement("strong", null, "What does it tell"),
            React.createElement("p", null, "The statistics about the potential application for each KI can be found in HIRO KIM. The statistics can give you an indication if the quality of the affected KI is sufficient or if improvement is required"))),
        value: counts.validation,
        action: function () { return openKim('deployed'); },
    },
    {
        title: (React.createElement("span", null,
            React.createElement("b", null, "Undeployed"),
            " Knowledge Items")),
        description: (React.createElement("div", null,
            React.createElement("strong", null, "What it is:"),
            React.createElement("p", null, "If a KI is not being deployed into the testing or live mode from HIRO KAT - the KI will remain in the underplayed state. Like that the affected KI will not be tested or applied in an automation process"),
            React.createElement("strong", null, "When is this useful"),
            React.createElement("p", null, "In case you are still working on a KI or want to ask a peer for review - it makes sense to leave the KI in the Undeployed state."))),
        value: counts.undeployed,
        action: function () { return openKim('undeployed'); },
    },
    {
        title: (React.createElement("span", null,
            React.createElement("b", null, "Live"),
            " Knowledge Items")),
        description: (React.createElement("div", null,
            React.createElement("strong", null, "What it is:"),
            React.createElement("p", null, "If you deploy a KI into the Live Mode, this KI will be triggered during automation solution creation and will help to solve automation tasks"),
            React.createElement("strong", null, "Where can I inspect this?"),
            React.createElement("p", null, "All statistics about the performance of a KI no matter if in live or test mode can be found in the HIRO KI Manager application (KIM)"))),
        value: counts.deployed,
        action: function () { return openKim('validation'); },
    },
    {
        title: 'Total Knowledge Items available',
        description: '',
        value: counts.total,
        primary: true,
        action: openKim,
    },
]; };
